/**
 * JASMINe
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eventswitch.endpoints;

import org.mule.umo.UMOException;
import org.mule.umo.endpoint.EndpointException;
import org.mule.umo.lifecycle.Startable;
import org.mule.umo.lifecycle.Stoppable;
import org.ow2.jasmine.monitoring.eventswitch.connectors.EJB3Connector;

/**
 * Defines an abstract EJB3 wrapper for Mule.
 */
public class MuleEJB3Wrapper<BeanType> extends EJB3Connector<BeanType> implements Startable, Stoppable {

    /**
     * See {@link MuleEJB3Wrapper#MuleEJB3Wrapper(boolean)},
     * parameter deferred.
     */
    private boolean deferred;

    /**
     * Initializes the EJB3 wrapper.
     *
     * @param deferred  If true, {@link EJB3Connector#connect()} is called when
     *                  {@link MuleEJB3Wrapper#start()} is called.
     *                  If false, {@link EJB3Connector#connect()} is called
     *                  when {@link EJB3Connector#getBean()} is called for the
     *                  first time.
     */
    protected MuleEJB3Wrapper(final boolean deferred)  {
        this.deferred = deferred;
    }

    /**
     * Calls {@link EJB3Connector#connect()}.
     *
     * @see org.mule.umo.lifecycle.Startable#start()
     *
     * @throws UMOException  On naming failure.
     */
    public void start() throws UMOException {
        if(!deferred) {
            try {
                connect();
            } catch(Exception e) {
                throw new EndpointException(e);
            }
        }
    }

    /**
     * Calls {@link EJB3Connector#disconnect()}.
     *
     * @see org.mule.umo.lifecycle.Stoppable#stop()
     */
    public void stop() {
        disconnect();
    }
}
