/**
 * JASMINe
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.monitoring.eventswitch.tasks;

import java.util.HashMap;
import java.util.Map;
import java.util.TimerTask;

import org.mule.extras.client.MuleClient;
import org.mule.umo.UMOException;
import org.ow2.jasmine.event.beans.JasmineEventNotificationUpdate;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * Timer task that handle an update notification that couldn't be processed. The
 * message is sent back in the eventswitch on the specified endpointURI.
 *
 * @author Guillaume Renault
 */
public class DelayMessageTask extends TimerTask {

    /**
     * Logger.
     */
    private Log logger = LogFactory.getLog(DelayMessageTask.class);

    /**
     * The message to handle.
     */
    private Object message = null;

    /**
     * Endpoint URI.
     */
    private String endpointURI = null;

    /**
     * Constructor using the class fields.
     *
     * @param message The message to handle.
     * @param endpointURI the endpoint URI where to send the message back in the
     *        EventSwitch.
     */
    public DelayMessageTask(final Object message, final String endpointURI) {
        super();
        this.message = message;
        this.endpointURI = endpointURI;
    }

    @Override
    public void run() {
        try {
            MuleClient client = new MuleClient();
            Map<String, String> messageProperties = new HashMap<String, String>();
            messageProperties.put("version", "v1");
            client.dispatch(endpointURI, message, messageProperties);
            client.dispose();
        } catch (UMOException e) {
            this.logger.error("Error while sending back the notification to endpoint {0}. The error is :\n{1}", endpointURI, e
                .getDetailedMessage());
        }
    }

    /**
     * @return the endpointURI
     */
    public final String getEndpointURI() {
        return endpointURI;
    }

    /**
     * @param endpointURI the endpointURI to set
     */
    public final void setEndpointURI(final String endpointURI) {
        this.endpointURI = endpointURI;
    }

    /**
     * @return the message
     */
    public final Object getMessage() {
        return message;
    }

    /**
     * @param message the message to set
     */
    public final void setMessage(final JasmineEventNotificationUpdate message) {
        this.message = message;
    }

}
