/**
 * JASMINe
 * Copyright (C) 2008-2010 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eventswitch.transformers;

import org.mule.transformers.AbstractTransformer;
import org.mule.umo.transformer.TransformerException;
import org.ow2.jasmine.event.beans.JasmineEventEB;
import org.ow2.jasmine.event.messages.JasmineEvent;
import org.ow2.jasmine.event.messages.JasmineEventDetails;

/**
 * Class implementing a Mule transformer to format JasmineEvent and JasmineEventEB to CSV.
 */
public class JasmineEventToCSV extends AbstractTransformer {

    /**
     * CSV separator.
     */
    private static final String SEPARATOR = ";";

    /**
     * This attribute should be configurable;
     */
    private String dateFormat = "yyyy/mm/dd hh:mm:ss";

    public void setDateFormat(final String dateFormat) {
        this.dateFormat = dateFormat;
    }
    /**
     * Registers the transformer on Mule.
     *
     * @see org.mule.transformers.AbstractTransformer
     */
    public JasmineEventToCSV() {
        super();
        this.registerSourceType(JasmineEvent.class);
        this.registerSourceType(JasmineEventEB.class);
        this.setReturnClass(String.class);
    }


    /**
     * Transforms a JASMINe event into CVS string.
     *
     * @param src      @see org.mule.transformers.AbstractTransformer.doTransform
     * @param encoding @see org.mule.transformers.AbstractTransformer.doTransform
     *
     * @return src transformed into a CSV string.
     */
    @Override
    protected Object doTransform(final Object src, final String encoding) throws TransformerException {

        StringBuffer buffer = new StringBuffer();

        if (src instanceof JasmineEvent) {
            JasmineEvent event = (JasmineEvent) src;

            String domain = event.getDomain();
            String server = event.getServer();

            for (JasmineEventDetails ed : event.getEvents()) {

                String formatedDate = JasmineDateFormater.getDateFormat(ed.getTimestamp());

                buffer.append(ed.getTimestamp().getTime());
                buffer.append(SEPARATOR);
                buffer.append(formatedDate);
                buffer.append(SEPARATOR);
                buffer.append(ed.getSname());
                buffer.append(SEPARATOR);
                buffer.append(domain);
                buffer.append(SEPARATOR);
                buffer.append(server);
                buffer.append(SEPARATOR);
                buffer.append(ed.getProbe());
                buffer.append(SEPARATOR);
                buffer.append(ed.getValue());
                buffer.append("\n");
            }

        } else if (src instanceof JasmineEventEB) {
            JasmineEventEB event = (JasmineEventEB) src;

            String formatedDate = JasmineDateFormater.getDateFormat(event.getTimestamp());

            buffer.append(event.getTimestamp().getTime());
            buffer.append(SEPARATOR);
            buffer.append(formatedDate);
            buffer.append(SEPARATOR);
            buffer.append(event.getSname());
            buffer.append(SEPARATOR);
            buffer.append(event.getDomain());
            buffer.append(SEPARATOR);
            buffer.append(event.getServer());
            buffer.append(SEPARATOR);
            buffer.append(event.getProbe());
            buffer.append(SEPARATOR);
            buffer.append(event.getValue());
            buffer.append("\n");

        } else {
            throw new IllegalArgumentException("Unable to transform this source type: " + src.getClass().getName());
        }

        return buffer.toString();
    }
}
